==> ginkgo-1.4.0.tar.gz: ginkgo-1.4.0/core/factorization/par_ic_kernels.hpp <==
/*******************************<GINKGO LICENSE>******************************
Copyright (c) 2017-2021, the Ginkgo authors
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its
contributors may be used to endorse or promote products derived from
this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
******************************<GINKGO LICENSE>*******************************/

#ifndef GKO_CORE_FACTORIZATION_PAR_IC_KERNELS_HPP_
#define GKO_CORE_FACTORIZATION_PAR_IC_KERNELS_HPP_


#include <ginkgo/core/factorization/par_ic.hpp>


#include <memory>


#include <ginkgo/core/base/executor.hpp>
#include <ginkgo/core/base/types.hpp>
#include <ginkgo/core/matrix/coo.hpp>
#include <ginkgo/core/matrix/csr.hpp>


namespace gko {
namespace kernels {


#define GKO_DECLARE_PAR_IC_INIT_FACTOR_KERNEL(ValueType, IndexType) \
    void init_factor(std::shared_ptr<const DefaultExecutor> exec,   \
                     matrix::Csr<ValueType, IndexType> *l_factor)

#define GKO_DECLARE_PAR_IC_COMPUTE_FACTOR_KERNEL(ValueType, IndexType)     \
    void compute_factor(                                                   \
        std::shared_ptr<const DefaultExecutor> exec, size_type iterations, \
        const matrix::Coo<ValueType, IndexType> *lower_system_matrix,      \
        matrix::Csr<ValueType, IndexType> *l_factor)

#define GKO_DECLARE_ALL_AS_TEMPLATES                             \
    template <typename ValueType, typename IndexType>            \
    GKO_DECLARE_PAR_IC_INIT_FACTOR_KERNEL(ValueType, IndexType); \
    template <typename ValueType, typename IndexType>            \
    GKO_DECLARE_PAR_IC_COMPUTE_FACTOR_KERNEL(ValueType, IndexType)


namespace omp {
namespace par_ic_factorization {

GKO_DECLARE_ALL_AS_TEMPLATES;

}  // namespace par_ic_factorization
}  // namespace omp


namespace cuda {
namespace par_ic_factorization {

GKO_DECLARE_ALL_AS_TEMPLATES;

}  // namespace par_ic_factorization
}  // namespace cuda


namespace reference {
namespace par_ic_factorization {

GKO_DECLARE_ALL_AS_TEMPLATES;

}  // namespace par_ic_factorization
}  // namespace reference


namespace hip {
namespace par_ic_factorization {

GKO_DECLARE_ALL_AS_TEMPLATES;

}  // namespace par_ic_factorization
}  // namespace hip


namespace dpcpp {
namespace par_ic_factorization {

GKO_DECLARE_ALL_AS_TEMPLATES;

}  // namespace par_ic_factorization
}  // namespace dpcpp


#undef GKO_DECLARE_ALL_AS_TEMPLATES


}  // namespace kernels
}  // namespace gko


#endif  // GKO_CORE_FACTORIZATION_PAR_IC_KERNELS_HPP_

==> ginkgo-1.8.0.tar.gz: ginkgo-1.8.0/core/factorization/par_ic_kernels.hpp <==
// SPDX-FileCopyrightText: 2017 - 2024 The Ginkgo authors
//
// SPDX-License-Identifier: BSD-3-Clause

#ifndef GKO_CORE_FACTORIZATION_PAR_IC_KERNELS_HPP_
#define GKO_CORE_FACTORIZATION_PAR_IC_KERNELS_HPP_


#include <ginkgo/core/factorization/par_ic.hpp>


#include <memory>


#include <ginkgo/core/base/executor.hpp>
#include <ginkgo/core/base/types.hpp>
#include <ginkgo/core/matrix/coo.hpp>
#include <ginkgo/core/matrix/csr.hpp>


#include "core/base/kernel_declaration.hpp"


namespace gko {
namespace kernels {


#define GKO_DECLARE_PAR_IC_INIT_FACTOR_KERNEL(ValueType, IndexType) \
    void init_factor(std::shared_ptr<const DefaultExecutor> exec,   \
                     matrix::Csr<ValueType, IndexType>* l_factor)

#define GKO_DECLARE_PAR_IC_COMPUTE_FACTOR_KERNEL(ValueType, IndexType)     \
    void compute_factor(                                                   \
        std::shared_ptr<const DefaultExecutor> exec, size_type iterations, \
        const matrix::Coo<ValueType, IndexType>* lower_system_matrix,      \
        matrix::Csr<ValueType, IndexType>* l_factor)

#define GKO_DECLARE_ALL_AS_TEMPLATES                             \
    template <typename ValueType, typename IndexType>            \
    GKO_DECLARE_PAR_IC_INIT_FACTOR_KERNEL(ValueType, IndexType); \
    template <typename ValueType, typename IndexType>            \
    GKO_DECLARE_PAR_IC_COMPUTE_FACTOR_KERNEL(ValueType, IndexType)


GKO_DECLARE_FOR_ALL_EXECUTOR_NAMESPACES(par_ic_factorization,
                                        GKO_DECLARE_ALL_AS_TEMPLATES);


#undef GKO_DECLARE_ALL_AS_TEMPLATES


}  // namespace kernels
}  // namespace gko


#endif  // GKO_CORE_FACTORIZATION_PAR_IC_KERNELS_HPP_
